You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2023/12/22 05:39:33 UTC

(camel-spring-boot) branch main updated: CAMEL-19971: camel-consul - Migrate to a new project that is maintained

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel-spring-boot.git


The following commit(s) were added to refs/heads/main by this push:
     new 65b530111ac CAMEL-19971: camel-consul - Migrate to a new project that is maintained
65b530111ac is described below

commit 65b530111ac8524ee5224529874056fc37f3df46
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Fri Dec 22 06:39:25 2023 +0100

    CAMEL-19971: camel-consul - Migrate to a new project that is maintained
---
 .../apache/camel/springboot/catalog/components/consul.json   | 12 ++++++------
 .../camel-consul-starter/src/main/docs/consul.json           | 10 +++++-----
 .../consul/springboot/ConsulComponentConfiguration.java      |  8 ++++----
 .../consul/springboot/ConsulComponentConverter.java          |  4 ++--
 .../springboot/cloud/ConsulServiceRegistryConfiguration.java |  2 +-
 .../cluster/ConsulClusterServiceConfiguration.java           |  2 +-
 6 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/consul.json b/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/consul.json
index 9b558df8980..367aeee9970 100644
--- a/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/consul.json
+++ b/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/consul.json
@@ -23,7 +23,7 @@
   },
   "componentProperties": {
     "connectTimeout": { "index": 0, "kind": "property", "displayName": "Connect Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Connect timeout for OkHttpClient" },
-    "consulClient": { "index": 1, "kind": "property", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "com.orbitz.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a com.orbitz.consul.Consul in the registry." },
+    "consulClient": { "index": 1, "kind": "property", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a org.kiwiproject.consul.Consul in the registry." },
     "key": { "index": 2, "kind": "property", "displayName": "Key", "group": "common", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The default key. Can be overridden by CamelConsulKey" },
     "pingInstance": { "index": 3, "kind": "property", "displayName": "Ping Instance", "group": "common", "label": "", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Configure if the AgentClient should attempt a ping before returning the Consul instance" },
     "readTimeout": { "index": 4, "kind": "property", "displayName": "Read Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Read timeout for OkHttpClient" },
@@ -36,7 +36,7 @@
     "valueAsString": { "index": 11, "kind": "property", "displayName": "Value As String", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Default to transform values retrieved from Consul i.e. on KV endpoint to string." },
     "autowiredEnabled": { "index": 12, "kind": "property", "displayName": "Autowired Enabled", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "description": "Whether autowiring is enabled. This is used for automatic autowiring options (the option must be marked as autowired) by looking up in the registry to find if there is a single instance of matching  [...]
     "configuration": { "index": 13, "kind": "property", "displayName": "Configuration", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.apache.camel.component.consul.ConsulConfiguration", "deprecated": false, "autowired": false, "secret": false, "description": "Consul configuration" },
-    "consistencyMode": { "index": 14, "kind": "property", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "com.orbitz.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description":  [...]
+    "consistencyMode": { "index": 14, "kind": "property", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "descripti [...]
     "datacenter": { "index": 15, "kind": "property", "displayName": "Datacenter", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The data center" },
     "nearNode": { "index": 16, "kind": "property", "displayName": "Near Node", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The near node to use for queries." },
     "nodeMeta": { "index": 17, "kind": "property", "displayName": "Node Meta", "group": "advanced", "label": "advanced", "required": false, "type": "array", "javaType": "java.util.List<java.lang.String>", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The note meta-data to use for queries." },
@@ -76,16 +76,16 @@
     "CamelConsulNodeMeta": { "index": 23, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "List<String>", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The note meta-data to use for queries.", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_NODE_META" },
     "CamelConsulLastContact": { "index": 24, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "Long", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The last contact", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_LAST_CONTACT" },
     "CamelConsulKnownLeader": { "index": 25, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Indicates whether it is the known leader", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_KNOWN_LEADER" },
-    "CamelConsulConsistencyMode": { "index": 26, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "com.orbitz.consul.option.ConsistencyMode", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "DEFAULT", "description": "The consistencyMode used for queries", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_CONSISTENCY_MODE" },
+    "CamelConsulConsistencyMode": { "index": 26, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "org.kiwiproject.consul.option.ConsistencyMode", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "DEFAULT", "description": "The consistencyMode used for queries", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_CONSISTENCY_MODE" },
     "CamelConsulHealthyOnly": { "index": 27, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "false", "description": "Only on healthy services", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_HEALTHY_ONLY" },
-    "CamelConsulHealthyState": { "index": 28, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "com.orbitz.consul.model.State", "enum": [ "PASS", "WARN", "FAIL", "ANY", "UNKNOWN" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The state to query.", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_HEALTHY_STATE" },
+    "CamelConsulHealthyState": { "index": 28, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "org.kiwiproject.consul.model.State", "enum": [ "PASS", "WARN", "FAIL", "ANY", "UNKNOWN" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The state to query.", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_HEALTHY_STATE" },
     "CamelConsulPreparedQueryID": { "index": 29, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The id of the prepared query", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_PREPARED_QUERY_ID" },
     "CamelConsulServiceId": { "index": 30, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The service id for agent deregistration", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_SERVICE_ID" }
   },
   "properties": {
     "apiEndpoint": { "index": 0, "kind": "path", "displayName": "Api Endpoint", "group": "common", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The API endpoint" },
     "connectTimeout": { "index": 1, "kind": "parameter", "displayName": "Connect Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Connect timeout for OkHttpClient" },
-    "consulClient": { "index": 2, "kind": "parameter", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "com.orbitz.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a com.orbitz.consul.Consul in the registry." },
+    "consulClient": { "index": 2, "kind": "parameter", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a org.kiwiproject.consul.Consul in the registry." },
     "key": { "index": 3, "kind": "parameter", "displayName": "Key", "group": "common", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The default key. Can be overridden by CamelConsulKey" },
     "pingInstance": { "index": 4, "kind": "parameter", "displayName": "Ping Instance", "group": "common", "label": "", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Configure if the AgentClient should attempt a ping before returning the Consul instance" },
     "readTimeout": { "index": 5, "kind": "parameter", "displayName": "Read Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Read timeout for OkHttpClient" },
@@ -98,7 +98,7 @@
     "action": { "index": 12, "kind": "parameter", "displayName": "Action", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The default action. Can be overridden by CamelConsulAction" },
     "valueAsString": { "index": 13, "kind": "parameter", "displayName": "Value As String", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Default to transform values retrieved from Consul i.e. on KV endpoint to string." },
     "lazyStartProducer": { "index": 14, "kind": "parameter", "displayName": "Lazy Start Producer", "group": "producer (advanced)", "label": "producer,advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a produ [...]
-    "consistencyMode": { "index": 15, "kind": "parameter", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "com.orbitz.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": [...]
+    "consistencyMode": { "index": 15, "kind": "parameter", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "descript [...]
     "datacenter": { "index": 16, "kind": "parameter", "displayName": "Datacenter", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The data center" },
     "nearNode": { "index": 17, "kind": "parameter", "displayName": "Near Node", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The near node to use for queries." },
     "nodeMeta": { "index": 18, "kind": "parameter", "displayName": "Node Meta", "group": "advanced", "label": "advanced", "required": false, "type": "array", "javaType": "java.util.List<java.lang.String>", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The note meta-data to use for queries." },
diff --git a/components-starter/camel-consul-starter/src/main/docs/consul.json b/components-starter/camel-consul-starter/src/main/docs/consul.json
index 67b95b6b8a2..bb4cfda9226 100644
--- a/components-starter/camel-consul-starter/src/main/docs/consul.json
+++ b/components-starter/camel-consul-starter/src/main/docs/consul.json
@@ -64,7 +64,7 @@
     },
     {
       "name": "camel.cloud.consul.consistency-mode",
-      "type": "com.orbitz.consul.option.ConsistencyMode",
+      "type": "org.kiwiproject.consul.option.ConsistencyMode",
       "description": "The consistencyMode used for queries, default ConsistencyMode.DEFAULT",
       "sourceType": "org.apache.camel.component.consul.springboot.cloud.ConsulServiceRegistryConfiguration"
     },
@@ -222,7 +222,7 @@
     },
     {
       "name": "camel.cluster.consul.consistency-mode",
-      "type": "com.orbitz.consul.option.ConsistencyMode",
+      "type": "org.kiwiproject.consul.option.ConsistencyMode",
       "description": "The consistencyMode used for queries, default ConsistencyMode.DEFAULT",
       "sourceType": "org.apache.camel.component.consul.springboot.cluster.ConsulClusterServiceConfiguration"
     },
@@ -401,14 +401,14 @@
     },
     {
       "name": "camel.component.consul.consistency-mode",
-      "type": "com.orbitz.consul.option.ConsistencyMode",
+      "type": "org.kiwiproject.consul.option.ConsistencyMode",
       "description": "The consistencyMode used for queries, default ConsistencyMode.DEFAULT",
       "sourceType": "org.apache.camel.component.consul.springboot.ConsulComponentConfiguration"
     },
     {
       "name": "camel.component.consul.consul-client",
-      "type": "com.orbitz.consul.Consul",
-      "description": "Reference to a com.orbitz.consul.Consul in the registry. The option is a com.orbitz.consul.Consul type.",
+      "type": "org.kiwiproject.consul.Consul",
+      "description": "Reference to a org.kiwiproject.consul.Consul in the registry. The option is a org.kiwiproject.consul.Consul type.",
       "sourceType": "org.apache.camel.component.consul.springboot.ConsulComponentConfiguration"
     },
     {
diff --git a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConverter.java b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConverter.java
index 43199a2b0b2..5b81200dcc3 100644
--- a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConverter.java
+++ b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConverter.java
@@ -40,7 +40,7 @@ public class ConsulComponentConverter implements GenericConverter {
     public Set<ConvertiblePair> getConvertibleTypes() {
         Set<ConvertiblePair> answer = new LinkedHashSet<>();
         answer.add(new ConvertiblePair(String.class, java.time.Duration.class));
-        answer.add(new ConvertiblePair(String.class, com.orbitz.consul.Consul.class));
+        answer.add(new ConvertiblePair(String.class, org.kiwiproject.consul.Consul.class));
         answer.add(new ConvertiblePair(String.class, org.apache.camel.component.consul.ConsulConfiguration.class));
         answer.add(new ConvertiblePair(String.class, org.apache.camel.support.jsse.SSLContextParameters.class));
         answer.add(new ConvertiblePair(String.class, java.math.BigInteger.class));
@@ -61,7 +61,7 @@ public class ConsulComponentConverter implements GenericConverter {
         ref = ref.startsWith("#bean:") ? ref.substring(6) : ref.substring(1);
         switch (targetType.getName()) {
             case "java.time.Duration": return applicationContext.getBean(ref, java.time.Duration.class);
-            case "com.orbitz.consul.Consul": return applicationContext.getBean(ref, com.orbitz.consul.Consul.class);
+            case "org.kiwiproject.consul.Consul": return applicationContext.getBean(ref, org.kiwiproject.consul.Consul.class);
             case "org.apache.camel.component.consul.ConsulConfiguration": return applicationContext.getBean(ref, org.apache.camel.component.consul.ConsulConfiguration.class);
             case "org.apache.camel.support.jsse.SSLContextParameters": return applicationContext.getBean(ref, org.apache.camel.support.jsse.SSLContextParameters.class);
             case "java.math.BigInteger": return applicationContext.getBean(ref, java.math.BigInteger.class);
diff --git a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cloud/ConsulServiceRegistryConfiguration.java b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cloud/ConsulServiceRegistryConfiguration.java
index 00adfe2face..4dd6b295f25 100644
--- a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cloud/ConsulServiceRegistryConfiguration.java
+++ b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cloud/ConsulServiceRegistryConfiguration.java
@@ -22,7 +22,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import com.orbitz.consul.option.ConsistencyMode;
+import org.kiwiproject.consul.option.ConsistencyMode;
 
 import org.apache.camel.support.jsse.SSLContextParameters;
 import org.springframework.boot.context.properties.ConfigurationProperties;
diff --git a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cluster/ConsulClusterServiceConfiguration.java b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cluster/ConsulClusterServiceConfiguration.java
index 145e0b0107f..a2a077f3b3b 100644
--- a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cluster/ConsulClusterServiceConfiguration.java
+++ b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/cluster/ConsulClusterServiceConfiguration.java
@@ -22,7 +22,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import com.orbitz.consul.option.ConsistencyMode;
+import org.kiwiproject.consul.option.ConsistencyMode;
 
 import org.apache.camel.component.consul.cluster.ConsulClusterConfiguration;
 import org.apache.camel.support.jsse.SSLContextParameters;
diff --git a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java
index 488b2d1c45d..88ecb890c5c 100644
--- a/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java
+++ b/components-starter/camel-consul-starter/src/main/java/org/apache/camel/component/consul/springboot/ConsulComponentConfiguration.java
@@ -19,12 +19,12 @@ package org.apache.camel.component.consul.springboot;
 import java.math.BigInteger;
 import java.time.Duration;
 import java.util.List;
-import com.orbitz.consul.Consul;
-import com.orbitz.consul.option.ConsistencyMode;
 import org.apache.camel.component.consul.ConsulComponent;
 import org.apache.camel.component.consul.ConsulConfiguration;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.apache.camel.support.jsse.SSLContextParameters;
+import org.kiwiproject.consul.Consul;
+import org.kiwiproject.consul.option.ConsistencyMode;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 
 /**
@@ -48,8 +48,8 @@ public class ConsulComponentConfiguration
      */
     private Duration connectTimeout;
     /**
      * Reference to a com.orbitz.consul.Consul in the registry. The option is a
      * com.orbitz.consul.Consul type.
      */
     private Consul consulClient;
     /**
@@ -48,8 +48,8 @@ public class ConsulComponentConfiguration
     private Duration connectTimeout;
     /**
-     * Reference to a com.orbitz.consul.Consul in the registry. The option is a
-     * com.orbitz.consul.Consul type.
+     * Reference to a org.kiwiproject.consul.Consul in the registry. The option
+     * is a org.kiwiproject.consul.Consul type.
      */
     private Consul consulClient;